import { ContentElement } from '@tailor-cms/interfaces/content-element';
import { Activity } from '@tailor-cms/interfaces/activity';

declare enum InsertLocation {
    AddBefore = "ADD_BEFORE",
    AddAfter = "ADD_AFTER",
    AddInto = "ADD_INTO",
    Reorder = "REORDER"
}

type Item = Activity | ContentElement;
interface PositionConfig {
    newPosition: number;
    items: Item[];
    isFirstChild?: boolean;
    action?: InsertLocation;
    count?: number;
}
declare const getPositions: (items: Item[], index: number, count?: number) => number[];
/**
 * Calculates item position(s) based on the options provided.
 * @param {number} config.newPosition The index of the anchor item by which the new
 *     positions will be calculated. Defaults to the end of the `items` array.
 * @param {Object[]} config.items An array of objects in which we are determining
 *     item's new position.
 * @param {boolean} config.isFirstChild Deprecated: Boolean value denoting whether
 *     the item should be placed as the first child of its parent.
 * @param {InsertLocation} [config.action=Reorder]
 *     A string value determining where the item should be placed
 *     in relation to `newPosition`.
 *     AddBefore returns position(s) placed before the anchor element.
 *     AddAfter returns position(s) placed after the anchor element.
 *     Reorder returns calculated position(s) based on `position` property of
 *     adjacent elements.
 *     Defaults to Reorder.
 * @param {number} config.count A number of items for which position needs to be
 *     determinate.
 * @return {(number|Array)} Single position if `count` is 1 or an array containing
 *     `count` positions.
 */
declare function calculatePosition(config: PositionConfig): number | number[];

interface NodeProcessor {
    filterNodesFn?: (it: Activity[]) => Activity[];
    processNodeFn?: (it: Activity) => any;
}
interface Internals {
    parentId?: number;
    level?: number;
    maxLevel?: number;
}
declare function isChanged(activity: Activity): boolean;
declare function doesRequirePublishing(activity: Activity): boolean;
declare function getParent(activities: Activity[], activity: Activity): Activity;
declare function getChildren(activities: Activity[], parentId: number): Activity[];
declare function getDescendants(activities: Activity[], activity: Activity): Activity[];
declare function getAncestors(activities: Activity[], activity: Activity): Activity[];
declare function toTreeFormat(activities: Activity[], processors: NodeProcessor, _internals?: Internals): Activity[];

declare const activity_doesRequirePublishing: typeof doesRequirePublishing;
declare const activity_getAncestors: typeof getAncestors;
declare const activity_getChildren: typeof getChildren;
declare const activity_getDescendants: typeof getDescendants;
declare const activity_getParent: typeof getParent;
declare const activity_isChanged: typeof isChanged;
declare const activity_toTreeFormat: typeof toTreeFormat;
declare namespace activity {
  export { activity_doesRequirePublishing as doesRequirePublishing, activity_getAncestors as getAncestors, activity_getChildren as getChildren, activity_getDescendants as getDescendants, activity_getParent as getParent, activity_isChanged as isChanged, activity_toTreeFormat as toTreeFormat };
}

declare const lowerCase: (value: string) => string;
declare const constantCase: (value: string) => Uppercase<string>;
declare const sentenceCase: (value: string) => string;
declare const titleCase: (value: string) => string;

declare enum DiscussionEvents {
    Save = "comment:save",
    Remove = "comment:remove",
    SetLastSeen = "comment:setLastSeen",
    Resolve = "element:resolveComments"
}

declare namespace index {
  export { DiscussionEvents as Discussion };
}

declare const _default$1: (n: number) => string;

declare enum PublishDiffChangeTypes {
    New = "new",
    Changed = "changed",
    Removed = "removed"
}

declare const _default: () => string;

declare const getMetaName: (type: string) => string;
declare const getContainerName: (type: string) => string;
declare const getComponentName: (type: string) => string;
declare const getToolbarName: (type: string) => string;
declare const getSidebarName: (type: string) => string;
declare const getElementId: (element: ContentElement) => string | number;
declare const getQuestionPromptPreview: (elements: ContentElement[]) => string;

export { index as Events, InsertLocation, PublishDiffChangeTypes, activity, calculatePosition, constantCase, getComponentName, getContainerName, getElementId, getMetaName, getPositions, getQuestionPromptPreview, getSidebarName, getToolbarName, lowerCase, _default$1 as numberToLetter, sentenceCase, titleCase, _default as uuid };
