var __defProp = Object.defineProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};

// src/index.ts
import { filter as filter2, kebabCase, map } from "lodash-es";

// src/insertLocation.ts
var InsertLocation = /* @__PURE__ */ ((InsertLocation2) => {
  InsertLocation2["AddBefore"] = "ADD_BEFORE";
  InsertLocation2["AddAfter"] = "ADD_AFTER";
  InsertLocation2["AddInto"] = "ADD_INTO";
  InsertLocation2["Reorder"] = "REORDER";
  return InsertLocation2;
})(InsertLocation || {});
var insertLocation_default = InsertLocation;

// src/calculatePosition.ts
var { AddAfter, Reorder } = insertLocation_default;
var distributePositions = ({ lower = 0, upper = 0 }, count) => {
  const delta = upper ? (upper - lower) / (count + 1) : 1;
  return Array.from({ length: count }).map((_, i) => delta * (i + 1) + lower);
};
function getDeprecationWarning(config) {
  if (!Object.hasOwn(config, "isFirstChild")) return;
  console.warn(`Deprecation notice:
    'isFirstChild' option is deprecated and no longer used!
    Providing it does not affect this function.`);
}
var getPositions = (items, index, count = 1) => {
  const { position: lower } = items[index - 1] || {};
  const { position: upper } = items[index] || {};
  return distributePositions({ lower, upper }, count);
};
function calculatePosition(config) {
  const { newPosition, items, action = Reorder, count = 1 } = config;
  getDeprecationWarning(config);
  const arr = [...items];
  if (action === Reorder) arr.splice(newPosition, count);
  let index = items.length;
  if (newPosition !== void 0) {
    index = action === AddAfter ? newPosition + 1 : newPosition;
  }
  const positions = getPositions(arr, index, count);
  return count === 1 ? positions[0] : positions;
}

// src/activity.ts
var activity_exports = {};
__export(activity_exports, {
  doesRequirePublishing: () => doesRequirePublishing,
  getAncestors: () => getAncestors,
  getChildren: () => getChildren,
  getDescendants: () => getDescendants,
  getParent: () => getParent,
  isChanged: () => isChanged,
  toTreeFormat: () => toTreeFormat
});
import { filter, find, get, sortBy } from "lodash-es";
function isChanged(activity) {
  return !activity.publishedAt || new Date(activity.modifiedAt) > new Date(activity.publishedAt);
}
function doesRequirePublishing(activity) {
  if (!activity.publishedAt) return false;
  if (!activity.deletedAt) return false;
  const dateDeleted = new Date(activity.deletedAt).getTime();
  const datePublished = new Date(activity.publishedAt).getTime();
  return dateDeleted > datePublished;
}
function getParent(activities, activity) {
  const id = get(activity, "parentId", null);
  return id && find(activities, { id });
}
function getChildren(activities, parentId) {
  return sortBy(filter(activities, { parentId }), "position");
}
function getDescendants(activities, activity) {
  const children = filter(activities, { parentId: activity.id });
  if (!children.length) return [];
  const reducer = (acc, it) => {
    return acc.concat(getDescendants(activities, it));
  };
  const descendants = children.reduce(reducer, []);
  return children.concat(descendants);
}
function getAncestors(activities, activity) {
  const parent = find(activities, { id: activity.parentId });
  if (!parent) return [];
  const ancestors = getAncestors(activities, parent);
  return [...ancestors, parent];
}
function toTreeFormat(activities, processors, _internals = {}) {
  const { filterNodesFn = (it) => it, processNodeFn } = processors;
  const { parentId = null, level = 1, maxLevel = 20 } = _internals;
  if (level > maxLevel) throw new Error("Max level exceeded");
  const parentActivities = filter(activities, { parentId });
  return filterNodesFn(parentActivities).map((activity) => ({
    ...activity,
    name: activity.data.name,
    title: activity.data.name,
    level,
    children: toTreeFormat(
      activities,
      { filterNodesFn, processNodeFn },
      {
        ..._internals,
        parentId: activity.id,
        level: level + 1
      }
    ),
    ...processNodeFn && processNodeFn(activity)
  }));
}

// src/changeCase.ts
import { capitalize, words, toLower, snakeCase, toUpper } from "lodash-es";
var minorWords = /* @__PURE__ */ new Set([
  "a",
  "an",
  "and",
  "as",
  "at",
  "but",
  "by",
  "en",
  "for",
  "from",
  "how",
  "if",
  "in",
  "neither",
  "nor",
  "of",
  "on",
  "only",
  "onto",
  "out",
  "or",
  "per",
  "so",
  "than",
  "that",
  "the",
  "to",
  "until",
  "up",
  "upon",
  "v",
  "v.",
  "versus",
  "vs",
  "vs.",
  "via",
  "when",
  "with",
  "without",
  "yet"
]);
var lowerCase = (value) => words(value).map(toLower).join(" ");
var constantCase = (value) => toUpper(snakeCase(value));
var sentenceCase = (value) => capitalize(lowerCase(value));
var titleCase = (value) => words(value).map((word, index, arr) => {
  const lower = toLower(word);
  const isMinorWord = minorWords.has(lower);
  const isFirstOrLast = index === 0 || index === arr.length - 1;
  return isFirstOrLast || !isMinorWord ? capitalize(lower) : lower;
}).join(" ");

// src/events/index.ts
var events_exports = {};
__export(events_exports, {
  Discussion: () => discussion_default
});

// src/events/discussion.ts
var DiscussionEvents = /* @__PURE__ */ ((DiscussionEvents2) => {
  DiscussionEvents2["Save"] = "comment:save";
  DiscussionEvents2["Remove"] = "comment:remove";
  DiscussionEvents2["SetLastSeen"] = "comment:setLastSeen";
  DiscussionEvents2["Resolve"] = "element:resolveComments";
  return DiscussionEvents2;
})(DiscussionEvents || {});
var discussion_default = DiscussionEvents;

// src/numberToLetter.ts
var alphabet = "ABCDEFGHIJKLMNOPQRSTUVWXYZ";
var base = alphabet.length;
var numberToLetter_default = (n) => {
  const digits = [];
  do {
    const v = n % base;
    digits.push(v);
    n = Math.floor(n / base);
  } while (n-- > 0);
  const chars = [];
  while (digits.length) {
    chars.push(alphabet[digits.pop()]);
  }
  return chars.join("");
};

// src/publishDiffChangeTypes.ts
var PublishDiffChangeTypes = /* @__PURE__ */ ((PublishDiffChangeTypes2) => {
  PublishDiffChangeTypes2["New"] = "new";
  PublishDiffChangeTypes2["Changed"] = "changed";
  PublishDiffChangeTypes2["Removed"] = "removed";
  return PublishDiffChangeTypes2;
})(PublishDiffChangeTypes || {});
var publishDiffChangeTypes_default = PublishDiffChangeTypes;

// src/uuid.ts
import { v4 } from "uuid";
var uuid_default = () => v4();

// src/index.ts
var TEXT_CONTAINERS = ["HTML", "JODIT_HTML", "TIPTAP_HTML"];
var blankRegex = /(@blank)/g;
var htmlRegex = /(<\/?[^>]+(>|$))|&nbsp;/g;
var getMetaName = (type) => `meta-${kebabCase(type)}`;
var getContainerName = (type) => `tcc-${kebabCase(type)}`;
var getComponentName = (type) => `tce-${kebabCase(type)}`;
var getToolbarName = (type) => `tce-${kebabCase(type)}-toolbar`;
var getSidebarName = (type) => `tce-${kebabCase(type)}-sidebar`;
var getElementId = (element) => element && (element.uid || element.id);
var getQuestionPromptPreview = (elements) => {
  const textAssets = filter2(elements, (it) => TEXT_CONTAINERS.includes(it.type));
  const questionText = map(textAssets, "data.content").join(" ");
  return questionText.replace(htmlRegex, "").replace(blankRegex, () => "____");
};
export {
  events_exports as Events,
  insertLocation_default as InsertLocation,
  publishDiffChangeTypes_default as PublishDiffChangeTypes,
  activity_exports as activity,
  calculatePosition,
  constantCase,
  getComponentName,
  getContainerName,
  getElementId,
  getMetaName,
  getPositions,
  getQuestionPromptPreview,
  getSidebarName,
  getToolbarName,
  lowerCase,
  numberToLetter_default as numberToLetter,
  sentenceCase,
  titleCase,
  uuid_default as uuid
};
